@@ -3,7 +3,7 @@
  * 
  * This file is part of BibORB
  * 
- * Copyright (C) 2003  Guillaume Gardey
+ * Copyright (C) 2003-2004  Guillaume Gardey
  * 
  * BibORB is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -25,7 +25,6 @@
  * 
  * File: config.php
  * Author: Guillaume Gardey (ggardey@club-internet.fr)
- * Year: 2003
  * Licence: GPL
  * 
  * Description:
@@ -34,8 +33,13 @@
  *    
  */
 
+/**
+ * Version of Biborb
+ */
+$biborb_version = "1.3";
+$date_release = "29 May 2004";
+
 
-  
 /**
  * If TRUE, this will disable authentification.
  * All users will have the administrator status
@@ -43,11 +47,26 @@
 $disable_authentication = TRUE;
 
 
+/**
+ *  Sould a confirmation may be displayed when deleting an entry
+ */
+$warn_before_deleting = TRUE;
+
 /**
  * Should the abstract be present for each entry.
  */
 $display_abstract = FALSE;
 
+/**
+ * Should action be represented by icons or not.
+ */
+$display_images = TRUE;
+
+/**
+ *  Sould action be represented by text or not.
+ */
+$display_text = FALSE;
+
 /**
  * Name of the PHP SESSION
  */
@@ -105,9 +124,51 @@ $bibtex_entries = array(
     "_link"
 );
 
+/**
+ * Choose which fields to save when exporting an entry to bibtex
+ * By default all fields are exported
+ */
+$fields_to_export = array('author',
+			  'address',
+			  'annote',
+			  'author',
+			  'booktitle',
+			  'chapter',
+			  'crossref',
+			  'edition',
+			  'editor',
+			  'howpublished',
+			  'institution',
+			  'journal',
+			  'key',
+			  'month',
+			  'note',
+			  'number',
+			  'organisation',
+			  'pages',
+			  'publisher',
+			  'school',
+			  'series',
+			  'title',
+			  'type',
+			  'volume',
+			  'year');
+
 /**
  * The CSS style file to use.
  */
 $CSS_FILE="style.css";
 
+/**
+ * Display sort in all/group/search view
+ * If no, displayed only on search
+ * true/no
+ */
+$DISPLAY_SORT="no";
+
+/**
+ * Default sort method: ID,title,year
+ */
+$DEFAULT_SORT="ID";
+
 ?>
